<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX Network Assistant</source>
        <translation>MX Verkkoavustin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>About...</source>
        <translation>Tietoja...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="109"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>Status</source>
        <translation>TIla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="225"/>
        <source>IP address</source>
        <translation>IP-osoite</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Hardware detected</source>
        <translation>Laitteisto havaittu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Enable</source>
        <translation>Ota käyttöön</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="303"/>
        <location filename="../mainwindow.ui" line="593"/>
        <location filename="../mainwindow.ui" line="706"/>
        <source>Re-scan</source>
        <translation>Läpikäy verkot uudelleen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Enabled</source>
        <translation>Käytössä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Interface</source>
        <translation>Käyttöliittymä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>Driver</source>
        <translation>Ajuri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>Description</source>
        <translation>Kuvaus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Vendor</source>
        <translation>Toimittaja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Product</source>
        <translation>Tuote</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="405"/>
        <source>Disable</source>
        <translation>Poista käytöstä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>Active interface</source>
        <translation>Aktiivinen käyttöliittymä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="435"/>
        <source>WiFi status</source>
        <translation>WiFi:n tila</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="457"/>
        <source>Unblocks all soft/hard blocked wireless devices</source>
        <translation>Poistaa kaikkien langattomien laitteiden estot</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>Unblock WiFi Devices</source>
        <translation>salli WiFi-laitteet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <source>Linux drivers</source>
        <translation>Linux-ajurit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Associated Linux drivers</source>
        <translation>Asiaan liittyvät Linux-ajurit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="513"/>
        <source>Load Driver</source>
        <translation>Lataa ajuri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>Unload Driver</source>
        <translation>Pura ajuri pois käytöstä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <location filename="../mainwindow.cpp" line="833"/>
        <source>Block Driver</source>
        <translation>Estä ajuri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="632"/>
        <source>Windows drivers</source>
        <translation>Windows-ajurit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="638"/>
        <source>Available Windows drivers</source>
        <translation>Käytettävissäolevat Windows-ajurit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <source>Remove Driver</source>
        <translation>Poista ajuri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="683"/>
        <source>Add Driver</source>
        <translation>Lisää ajuri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="724"/>
        <source>About NDISwrapper</source>
        <translation>Tietoa NDISwrapper:ista</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>Install NDISwrapper</source>
        <translation>Asenna NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>In order to use Windows drivers you need first to install NDISwrapper</source>
        <translation>Jotta voit käyttää Windows-ajureita sinun tulee ensin asentaa NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Uninstall NDISwrapper</source>
        <translation>Pura NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="795"/>
        <source>Net diagnostics</source>
        <translation>Verkon vianmääritys</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Ping</source>
        <translation>Ping-viive</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="813"/>
        <location filename="../mainwindow.ui" line="933"/>
        <source>Target URL:</source>
        <translation>Kohde URL:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="823"/>
        <source>Packets</source>
        <translation>Paketit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="868"/>
        <location filename="../mainwindow.ui" line="991"/>
        <source>Start</source>
        <translation>Aloita</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="885"/>
        <location filename="../mainwindow.ui" line="1008"/>
        <source>Clear</source>
        <translation>Tyhjennä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="899"/>
        <location filename="../mainwindow.ui" line="1022"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="927"/>
        <source>Traceroute</source>
        <translation>Traceroute</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="943"/>
        <source>Hops</source>
        <translation>Hops</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="86"/>
        <source>IP address from router:</source>
        <translation>IP-osoite reitittimeltä:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>External IP address:</source>
        <translation>Ulkoinen IP-osoite:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>Interface: %1</source>
        <translation>Käyttöliittymä: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="138"/>
        <source>Driver: %1</source>
        <translation>Ajuri: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>Description: %1</source>
        <translation>Kuvaus: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="140"/>
        <source>Product: %1</source>
        <translation>Tuote: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="141"/>
        <source>Vendor: %1</source>
        <translation>Toimittaja: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="127"/>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Enabled: %1</source>
        <translation>Käytössä: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="195"/>
        <location filename="../mainwindow.cpp" line="209"/>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopioi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <location filename="../mainwindow.cpp" line="211"/>
        <location filename="../mainwindow.cpp" line="225"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <location filename="../mainwindow.cpp" line="212"/>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Copy &amp;All</source>
        <translation>Kopioi &amp;Kaikki</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <location filename="../mainwindow.cpp" line="214"/>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Traceroute not installed</source>
        <translation>Traceroute ei ole asennettuna</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Traceroute is not installed, do you want to install it now?</source>
        <translation>Traceroute ei ole asennettuna, haluatko asentaa sen nyt?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Traceroute hasn&apos;t been installed</source>
        <translation>Traceroutea ei ole asennettu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
        <translation>Traceroutea ei voida asentaa. Tämä saattaa johtua että käytät LiveCD:tä tai yhteyden muodostus pakettivarastoon ei onnistu,</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
        <translation>Traceroute ei ole asennettuna eikä Internet-yhteyttä havaittu joten sitä ei voida asentaa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>No destination host</source>
        <translation>Määränpään isäntäasemaa ei ole</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Please fill in the destination host field</source>
        <translation>Täytä määränpään isäntäasemakenttä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <source>Loaded Drivers</source>
        <translation>Ladatut ajurit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>Unloaded Drivers</source>
        <translation>Lataamattomat ajurit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Blocked Drivers</source>
        <translation>Estetyt ajurit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>Blocked Broadcom Drivers</source>
        <translation>Estetyt Broadcom-ajurit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>Ndiswrapper is not installed</source>
        <translation>Ndiswrapper ei ole asennettuna</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>driver installed</source>
        <translation>ajuri asennettu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source> and in use by </source>
        <translation>ja tämän käytössä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>. Alternate driver: </source>
        <translation>. Vaihtoehtoinen ajuri: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist</source>
        <translation>Ajuri poistettu estoluettelosta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist.</source>
        <translation>Ajuri poistettu estoluettelosta.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="609"/>
        <source>Module blocked</source>
        <translation>Moduuli estetty</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <source>Installation successful</source>
        <translation>Asennus onnistui</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="765"/>
        <source>Error detected, could not compile ndiswrapper driver.</source>
        <translation>Virhe havaittu, ndiswrapper-ajuria ei voitu koota.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="768"/>
        <source>Error detected, could not install ndiswrapper.</source>
        <translation>Virhe havaittu, ndiswrapper-ajuria ei voitu asentaa.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="780"/>
        <source>Error encountered while removing Ndiswrapper</source>
        <translation>Virhe havaittu Ndiswrapper:in poistamisen aikana</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>Unblock Driver</source>
        <translation>Salli ajuri</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="862"/>
        <source>enabled</source>
        <translation>käytössä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="865"/>
        <source>disabled</source>
        <translation>poistettu käytöstä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="868"/>
        <source>WiFi hardware switch is off</source>
        <translation>WiFi-laitteistovipu on asennossa pois päältä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="875"/>
        <source>Locate the Windows driver you want to add</source>
        <translation>Paikallista Windows-ajurit jotka haluat lisätä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="876"/>
        <source>Windows installation information file (*.inf)</source>
        <translation>Windows-asennuksen tietopohjainen tiedosto (*.inf)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="907"/>
        <source>*.sys file not found</source>
        <translation>*.sys -tiedostoa ei löytynyt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
        <translation>*.sys tiedostot pitää olla samassa kohteessa kuin *.inf tiedosto. %1 ei löydetty</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="919"/>
        <source>sys file reference not found</source>
        <translation>sys-tiedostoviitettä ei löytynyt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="920"/>
        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
        <translation>Sys tiedostoa annetulle ajurille ei voida ennakoida inf-tiedoston jäsentämisen jälkeen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="937"/>
        <source>Ndiswrapper driver removed.</source>
        <translation>Ndiswrapper-ajuri poistettu.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>%1 Help</source>
        <translation>%1 Apuopas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="957"/>
        <source>Could not unlock devices.
WiFi device(s) might already be unlocked.</source>
        <translation>Laitteita ei onnistuttu avaamaan lukituksesta.
WiFi-laite (tai laitteet) ovat mahdollisesti jo avattu lukituksesta.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="959"/>
        <source>WiFi devices unlocked.</source>
        <translation>Wifi-laitteiden lukitus purettu.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="974"/>
        <source>About %1</source>
        <translation>%1 lisätietoja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="975"/>
        <source>Version: </source>
        <translation>Versio: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="976"/>
        <source>Program for troubleshooting and configuring network for MX Linux</source>
        <translation>Ohjelma ongelmanratkaisuun ja verkon asetuksiin MX Linux:issa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="978"/>
        <source>Copyright (c) MEPIS LLC and MX Linux</source>
        <translation>Tekijänoikeus (c) MEPIS LLC ja MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="979"/>
        <source>%1 License</source>
        <translation>%1 lupa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1005"/>
        <source>Driver loaded successfully</source>
        <translation>Ajuri ladattu onnistuneesti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1020"/>
        <source>Driver unloaded successfully</source>
        <translation>Ajuri onnistuneesti purettu.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>Muutosloki</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <location filename="../main.cpp" line="78"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Olet kirjautunut sisään pääkäyttäjänä. Kirjaudu sisään normaalina käyttäjänä käyttääksesi tätä ohjelmaa.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>You must run this program with admin access.</source>
        <translation>Tämä ohjelma on suoritettava järjestelmänvalvojan oikeuksilla.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Could not load </source>
        <translation>Ei voitu ladata</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="649"/>
        <source>Could not unload </source>
        <translation>Ei voitu ottaa pois käytöstä</translation>
    </message>
</context>
</TS>
